bayespy.nodes.Add
=================

.. currentmodule:: bayespy.nodes

.. autoclass:: Add

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Add.__init__
      ~Add.add_plate_axis
      ~Add.broadcasting_multiplier
      ~Add.delete
      ~Add.get_mask
      ~Add.get_moments
      ~Add.get_shape
      ~Add.has_plotter
      ~Add.lower_bound_contribution
      ~Add.move_plates
      ~Add.plot
      ~Add.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Add.plates
      ~Add.plates_multiplier
   
   